==> estateplat-common-1.1.0-20160902.030133-173-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSjxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记项目收件信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sjxx")
public class BdcSjxx implements Serializable,BdcProid,InsertVo {
    @Id
    private String sjxxid;//收件信息id

    private String proid; //不动产登记项目id

    private Date sjrq;//收件日期

    private String sjr;//收件人

    private String jjr;//交件人

    private String jjrdh;//交件人电话

    private String clqx;//承诺期限

    private String bz;//备注

    private String wiid;//工作流实例ID

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSjxxid() {
        return sjxxid;
    }

    public void setSjxxid(String sjxxid) {
        this.sjxxid = sjxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getJjr() {
        return jjr;
    }

    public void setJjr(String jjr) {
        this.jjr = jjr;
    }

    public String getJjrdh() {
        return jjrdh;
    }

    public void setJjrdh(String jjrdh) {
        this.jjrdh = jjrdh;
    }

    public String getClqx() {
        return clqx;
    }

    public void setClqx(String clqx) {
        this.clqx = clqx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.3-20180606.062015-109-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSjxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记项目收件信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sjxx")
public class BdcSjxx implements Serializable,BdcProid,InsertVo {
    @Id
    private String sjxxid;//收件信息id

    private String proid; //不动产登记项目id

    private Date sjrq;//收件日期

    private String sjr;//收件人

    private String jjr;//交件人

    private String jjrdh;//交件人电话

    private String clqx;//承诺期限

    private String bz;//备注

    private String wiid;//工作流实例ID

    private String dyzt;//打印状态

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSjxxid() {
        return sjxxid;
    }

    public void setSjxxid(String sjxxid) {
        this.sjxxid = sjxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getJjr() {
        return jjr;
    }

    public void setJjr(String jjr) {
        this.jjr = jjr;
    }

    public String getJjrdh() {
        return jjrdh;
    }

    public void setJjrdh(String jjrdh) {
        this.jjrdh = jjrdh;
    }

    public String getClqx() {
        return clqx;
    }

    public void setClqx(String clqx) {
        this.clqx = clqx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }
}
